@@ -39,15 +39,16 @@ number_translators=$(echo "$translators" | wc -l)
 
 # Output of common header
 echo "PO4A-HEADER:mode=after;position=^\.(TH|Dt);beginboundary=FakePo4aBoundary" > "$addendum"
-echo >> "$addendum"
 
 # Special case for manpages which use mdoc syntax
 if [ $ismdoc ]; then
     # MDOC File
-    echo ".Sh P◈EKLAD" >> "$addendum"
+    echo ".Pp" >> "$addendum"
+    echo ".Sh PŘEKLAD" >> "$addendum"
 else
     # Groff file
-    echo ".SH P◈EKLAD" >> "$addendum"
+    echo ".PP" >> "$addendum"
+    echo ".SH PŘEKLAD" >> "$addendum"
 fi
 echo "Překlad této příručky do španělštiny vytvořili" >> "$addendum"
 
